
package Google::Ads::AdWords::v201309::TypeMaps::CampaignCriterionService;
use strict;
use warnings;

our $typemap_1 = {
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'mutateResponse/rval/partialFailureErrors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/serviceSelector/predicates' => 'Google::Ads::AdWords::v201309::Predicate',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/partialFailureErrors[RegionCodeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::CampaignCriterionLimitExceeded',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'mutateResponse/rval/partialFailureErrors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RegionCodeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/serviceSelector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/reason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]' => 'Google::Ads::AdWords::v201309::SizeLimitError',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/reason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval' => 'Google::Ads::AdWords::v201309::CampaignCriterionPage',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201309::ClientTermsError',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]/reason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'mutate/operations/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'mutateResponse/rval/value/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]' => 'Google::Ads::AdWords::v201309::NotEmptyError',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/partialFailureErrors[RequestError]' => 'Google::Ads::AdWords::v201309::RequestError',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]' => 'Google::Ads::AdWords::v201309::AuthorizationError',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[NullError]' => 'Google::Ads::AdWords::v201309::NullError',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[BetaError]' => 'Google::Ads::AdWords::v201309::BetaError',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201309::ApiException',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/reason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201309::ReadOnlyError',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionError]' => 'Google::Ads::AdWords::v201309::CampaignCriterionError',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval/entries/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]' => 'Google::Ads::AdWords::v201309::AdxError',
               'getResponse/rval/entries/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'queryResponse/rval/entries/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201309::NewEntityCreationError',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]' => 'Google::Ads::AdWords::v201309::IdError',
               'mutate/operations/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get' => 'Google::Ads::AdWords::v201309::CampaignCriterionService::get',
               'mutate/operations/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/reason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201309::QuotaCheckError',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'queryResponse/rval/entries/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'mutateResponse/rval/value/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'mutateResponse/rval/value/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'mutate/operations/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionError]' => 'Google::Ads::AdWords::v201309::CampaignCriterionError',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'mutateResponse/rval/value/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'mutateResponse/rval/value/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'mutate/operations/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[PagingError]' => 'Google::Ads::AdWords::v201309::PagingError',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval/entries/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[RegionCodeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'mutate/operations/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval' => 'Google::Ads::AdWords::v201309::CampaignCriterionPage',
               'getResponse/rval/entries/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'mutateResponse/rval/value/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[PagingError]' => 'Google::Ads::AdWords::v201309::PagingError',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201309::RangeError',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval/entries/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/fields' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'queryResponse/rval/entries/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'mutate' => 'Google::Ads::AdWords::v201309::CampaignCriterionService::mutate',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'mutate/operations/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'mutate/operations/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResponse/rval/entries/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval/entries/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'mutateResponse/rval/partialFailureErrors[SelectorError]' => 'Google::Ads::AdWords::v201309::SelectorError',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'mutateResponse/rval/value/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/serviceSelector/predicates/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201309::CampaignCriterionReturnValue',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'mutate/operations/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector' => 'Google::Ads::AdWords::v201309::Selector',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/reason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'mutateResponse/rval/value/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201309::SelectorError',
               'mutateResponse/rval/value/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'mutate/operations/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RegionCodeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]' => 'Google::Ads::AdWords::v201309::RegionCodeError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201309::CampaignCriterion',
               'getResponse/rval/entries/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'mutateResponse/rval/partialFailureErrors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'mutate/operations/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval/entries/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'mutate/operations/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NullError]/reason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/partialFailureErrors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval/entries/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/reason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries' => 'Google::Ads::AdWords::v201309::CampaignCriterion',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]' => 'Google::Ads::AdWords::v201309::RateExceededError',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/predicates/values' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201309::AuthorizationError',
               'getResponse/rval/entries/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RangeError]/reason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::CampaignCriterionLimitExceeded::CriteriaLimitType',
               'getResponse/rval/entries/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]' => 'Google::Ads::AdWords::v201309::StringLengthError',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201309::RequestError',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201309::AuthenticationError',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'mutateResponse/rval/value/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval/entries/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResponse/rval/entries/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse' => 'Google::Ads::AdWords::v201309::CampaignCriterionService::mutateResponse',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'mutate/operations/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BetaError]/reason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]' => 'Google::Ads::AdWords::v201309::CriterionError',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201309::EntityNotFound',
               'mutate/operations/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]' => 'Google::Ads::AdWords::v201309::QuotaCheckError',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'queryResponse/rval/entries/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'mutate/operations/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutateResponse/rval/value/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval/entries/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'mutate/operations/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/ordering' => 'Google::Ads::AdWords::v201309::OrderBy',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'Fault/detail/ApiExceptionFault/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'mutateResponse/rval/partialFailureErrors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutate/operations/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'mutateResponse/rval/partialFailureErrors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'mutate/operations/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutate/operations/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutate/operations/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201309::ApiException',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'mutateResponse/rval/ListReturnValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'mutate/operations/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand' => 'Google::Ads::AdWords::v201309::CampaignCriterion',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations' => 'Google::Ads::AdWords::v201309::CampaignCriterionOperation',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors' => 'Google::Ads::AdWords::v201309::ApiError',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'mutate/operations/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/value/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'mutate/operations/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'queryResponse/rval/entries/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]' => 'Google::Ads::AdWords::v201309::ClientTermsError',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'mutateResponse/rval/value/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'get/serviceSelector/predicates/operator' => 'Google::Ads::AdWords::v201309::Predicate::Operator',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'mutate/operations/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BetaError]' => 'Google::Ads::AdWords::v201309::BetaError',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/partialFailureErrors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201309::InternalApiError',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'queryResponse/rval/entries/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'queryResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'queryResponse/rval/entries/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201309::DatabaseError',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/partialFailureErrors[RequestError]/reason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'query' => 'Google::Ads::AdWords::v201309::CampaignCriterionService::query',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'queryResponse/rval/entries/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201309::NotEmptyError',
               'getResponse/rval/entries/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/partialFailureErrors[CriterionError]' => 'Google::Ads::AdWords::v201309::CriterionError',
               'mutateResponse/rval/partialFailureErrors[RangeError]' => 'Google::Ads::AdWords::v201309::RangeError',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[IdError]/reason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'queryResponse/rval/entries/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval/entries/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/serviceSelector/ordering/sortOrder' => 'Google::Ads::AdWords::v201309::SortOrder',
               'get/serviceSelector/dateRange' => 'Google::Ads::AdWords::v201309::DateRange',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'mutateResponse/rval/value/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RegionCodeError]' => 'Google::Ads::AdWords::v201309::RegionCodeError',
               'mutateResponse/rval/value/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]' => 'Google::Ads::AdWords::v201309::NegativeCampaignCriterion',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201309::StringLengthError',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'mutateResponse/rval/partialFailureErrors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RegionCodeError]/reason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'mutateResponse/rval/value/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201309::NullError',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'queryResponse/rval/entries/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval/entries/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]' => 'Google::Ads::AdWords::v201309::AuthenticationError',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'mutate/operations/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201309::NotWhitelistedError',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'mutateResponse/rval/value/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/ordering/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval/entries/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'mutateResponse/rval/partialFailureErrors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201309::DistinctError',
               'mutateResponse/rval/partialFailureErrors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[IdError]' => 'Google::Ads::AdWords::v201309::IdError',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval/entries/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]' => 'Google::Ads::AdWords::v201309::DatabaseError',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]' => 'Google::Ads::AdWords::v201309::OperatorError',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]' => 'Google::Ads::AdWords::v201309::DistinctError',
               'getResponse/rval/entries/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]' => 'Google::Ads::AdWords::v201309::ReadOnlyError',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdxError]' => 'Google::Ads::AdWords::v201309::AdxError',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'mutateResponse/rval/partialFailureErrors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/serviceSelector/paging' => 'Google::Ads::AdWords::v201309::Paging',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201309::NewEntityCreationError',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]' => 'Google::Ads::AdWords::v201309::EntityNotFound',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval/entries/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201309::OperationAccessDenied',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/reason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]' => 'Google::Ads::AdWords::v201309::QueryError',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201309::RateExceededError',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]' => 'Google::Ads::AdWords::v201309::NegativeCampaignCriterion',
               'mutateResponse/rval/value/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'mutateResponse/rval/value[NegativeCampaignCriterion]' => 'Google::Ads::AdWords::v201309::NegativeCampaignCriterion',
               'mutate/operations/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval/entries/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse' => 'Google::Ads::AdWords::v201309::CampaignCriterionService::getResponse',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/reason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'queryResponse/rval/entries/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]' => 'Google::Ads::AdWords::v201309::RequiredError',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResponse/rval/entries[NegativeCampaignCriterion]' => 'Google::Ads::AdWords::v201309::NegativeCampaignCriterion',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'mutate/operations/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/partialFailureErrors[PagingError]/reason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResponse/rval/entries/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'get/serviceSelector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdxError]/reason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'queryResponse/rval/entries/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201309::SizeLimitError',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/reason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'queryResponse' => 'Google::Ads::AdWords::v201309::CampaignCriterionService::queryResponse',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'queryResponse/rval/entries/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'queryResponse/rval/entries/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'mutateResponse/rval/partialFailureErrors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201309::RequiredError',
               'queryResponse/rval/entries/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'mutate/operations/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]' => 'Google::Ads::AdWords::v201309::QueryError',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201309::OperationAccessDenied',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/serviceSelector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/partialFailureErrors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::CampaignCriterionLimitExceeded::CriteriaLimitType',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'mutateResponse/rval/partialFailureErrors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResponse/rval/entries/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'mutateResponse/rval/value/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'mutate/operations/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'queryResponse/rval/entries/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'queryResponse/rval/entries/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[OperatorError]' => 'Google::Ads::AdWords::v201309::OperatorError',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[IdError]/reason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201309::NotWhitelistedError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]' => 'Google::Ads::AdWords::v201309::InternalApiError',
               'mutateResponse/rval/value/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'mutateResponse/rval/value/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'query/query' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value' => 'Google::Ads::AdWords::v201309::CampaignCriterion',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'mutate/operations/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'mutate/operations/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/value/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'mutateResponse/rval/value/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/partialFailureErrors[CampaignCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/partialFailureErrors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeCampaignCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'queryResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/value/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201309::TypeMaps::CampaignCriterionService - typemap for CampaignCriterionService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

